@@ -1,8 +1,11 @@
 # IMPORTATION STANDARD
+
 # IMPORTATION THIRD PARTY
-# IMPORTATION INTERNAL
 from google.protobuf import json_format
 from google.protobuf.message import Message
+from google.protobuf.struct_pb2 import Struct
+
+# IMPORTATION INTERNAL
 
 
 def message_to_dict(message: Message) -> dict:
@@ -14,3 +17,12 @@ def message_to_dict(message: Message) -> dict:
         descriptor_pool=None,
         float_precision=None,
     )
+
+
+def struct_from_dict(json_dict: dict) -> Struct:
+    return json_format.ParseDict(
+        js_dict=json_dict,
+        message=Struct(),
+        ignore_unknown_fields=True,
+        descriptor_pool=None,
+    )
